==> dde-session-shell_5.5.69.orig.tar.xz: dde-session-shell-5.5.69/translations/dde-session-shell_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifikim i suksesshëm</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifikimi dështoi, edhe %n provë</numerusform><numerusform>Verifikimi dështoi, edhe %n prova</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifikimi dështoi, edhe një provë</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifikoni Face ID-në tuaj</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face ID e kyçur, ju lutemi, përdorni fjalëkalim</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifikoni shenjat tuaja të gishtave</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifikim i suksesshëm</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifikimi dështoi, edhe %n provë</numerusform><numerusform>Verifikimi dështoi, edhe %n prova</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifikimi dështoi, edhe një provë</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Shenja gishti të kyçura, ju lutemi, përdorni fjalëkalim</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iris ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifikim i suksesshëm</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifikimi dështoi, edhe %n provë</numerusform><numerusform>Verifikimi dështoi, edhe %n prova</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifikimi dështoi, edhe një provë</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifikoni Iris ID-në tuaj</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iris ID e kyçur, ju lutemi, përdorni fjalëkalimin</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifikim i suksesshëm</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifikimi dështoi, edhe %n provë</numerusform><numerusform>Verifikimi dështoi, edhe %n prova</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifikimi dështoi, edhe një provë</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Fjalëkalim i Gabuar</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Ju lutemi, riprovoni pas 1 minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Ju lutemi, riprovoni pas %n minute</numerusform><numerusform>Ju lutemi, riprovoni pas %n minutash</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Ricaktoni Fjalëkalimin</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Harruat fjalëkalimin?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Ju lutemi, riprovoni pas 1 minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Ju lutemi, riprovoni pas %n minute</numerusform><numerusform>Ju lutemi, riprovoni pas %n minutash</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Ricaktoni Fjalëkalimin</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Harruat fjalëkalimin?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifikim i suksesshëm</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifikimi dështoi, edhe %n provë</numerusform><numerusform>Verifikimi dështoi, edhe %n prova</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifikimi dështoi, edhe një provë</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN i Gabuar</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Lypset UKey</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Jepni PIN-in tuaj</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Ju lutemi, riprovoni %n minute</numerusform><numerusform>Ju lutemi, riprovoni %n minutash</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Ju lutemi, riprovoni pas 1 minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Ju lutemi, riprovoni pas %n minute</numerusform><numerusform>Ju lutemi, riprovoni pas %n minutash</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Llogari</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Fjalëkalimi juaj do të skadojë për %n ditë, ju lutemi, ndryshojeni në kohë</numerusform><numerusform>Fjalëkalimi juaj do të skadojë për %n ditë, ju lutemi, ndryshojeni në kohë</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Fjalëkalimi ndryshoi, ju lutemi, ndryshojeni</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Llogari e gabuar</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Fjalëkalim i Gabuar</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Kyçje Ekrani</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>S’u arrit të kyçet ekrani</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Verifikimit të shenjave të gishtit i mbaroi koha, ju lutemi, jepeni fjalëkalimin tuaj dorazi</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Shenjat e gishtit s’u përputhën</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Përdoruesit e mësipërm janë ende brenda llogarish dhe do të humbin të dhëna për shkak të fikjes, jeni i sigurt se doni të fiket?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Përdoruesit e mësipërm janë ende brenda llogarish dhe do të humbin të dhëna për shkak të rinisjes, jeni i sigurt se doni të riniset?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Keni aktivizuar shkallën e lartë të sigurisë së sistemit, ndaj s’mund të kalohet nën mënyrën Wayland, ju lutemi, çaktivizoni shkallën e lartë të sigurisë së sistemit që nga Qendra e Sigurisë dhe riprovoni.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Fike</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Rinisu</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pezulloje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Plogështoje</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kyçe</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Dilni</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Ndërroni përdorues</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Ndërroni sistem</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Nis mbikëqyrës sistemi</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Ka programe që e pengojnë fikjen e kompjuterit, dhe fikja me zor mund të sjellë humbje të dhënash.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Që të mbyllet programi, klikoni mbi “Anuloje”, dhe mandej mbyllni programin.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Ka programe që e pengojnë rinisjen e kompjuterit, dhe rinisja me zor mund të sjellë humbje të dhënash.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Ka programe që e pengojnë pezullimin e kompjuterit, dhe pezullimi me zor mund të sjellë humbje të dhënash.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Ka programe që e pengojnë plogështimin e kompjuterit, dhe plogështimi me zor mund të sjellë humbje të dhënash.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Ka programe që e pengojnë kompjuterin të bëjë dalje nga llogaria, dhe dalja me zor mund të sjellë humbje të dhënash.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Fike</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Rinisu</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pezulloje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Plogështoje</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Dilni</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Jeni i sigurt se doni të fiket?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Jeni i sigurt se doni të riniset?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Jeni i sigurt se doni të dilet?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Aktivizoje</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Çaktivizoje</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.100.2.orig.tar.xz: dde-session-shell-5.5.100.2/translations/dde-session-shell_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifikim i suksesshëm</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifikimi dështoi, edhe një provë</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifikoni Face ID-në tuaj</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face ID e kyçur, ju lutemi, përdorni fjalëkalim</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifikoni shenjat tuaja të gishtave</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifikim i suksesshëm</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifikimi dështoi, edhe %n provë</numerusform><numerusform>Verifikimi dështoi, edhe %n prova</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifikimi dështoi, edhe një provë</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Shenja gishti të kyçura, ju lutemi, përdorni fjalëkalim</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iris ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifikim i suksesshëm</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifikimi dështoi, edhe një provë</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifikoni Iris ID-në tuaj</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iris ID e kyçur, ju lutemi, përdorni fjalëkalimin</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifikim i suksesshëm</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifikimi dështoi, edhe %n provë</numerusform><numerusform>Verifikimi dështoi, edhe %n prova</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifikimi dështoi, edhe një provë</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Fjalëkalim i Gabuar</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Ju lutemi, riprovoni pas 1 minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Ricaktoni Fjalëkalimin</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Harruat fjalëkalimin?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Ju lutemi, riprovoni pas 1 minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Ju lutemi, riprovoni pas %n minute</numerusform><numerusform>Ju lutemi, riprovoni pas %n minutash</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Ricaktoni Fjalëkalimin</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Harruat fjalëkalimin?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifikim i suksesshëm</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifikimi dështoi, edhe %n provë</numerusform><numerusform>Verifikimi dështoi, edhe %n prova</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifikimi dështoi, edhe një provë</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN i Gabuar</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Lypset UKey</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Jepni PIN-in tuaj</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Ju lutemi, riprovoni %n minute</numerusform><numerusform>Ju lutemi, riprovoni %n minutash</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Ju lutemi, riprovoni pas 1 minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Llogari</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Fjalëkalimi ndryshoi, ju lutemi, ndryshojeni</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Llogari e gabuar</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Fjalëkalim i Gabuar</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Kyçje Ekrani</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>S’u arrit të kyçet ekrani</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Verifikimit të shenjave të gishtit i mbaroi koha, ju lutemi, jepeni fjalëkalimin tuaj dorazi</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Shenjat e gishtit s’u përputhën</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Përdoruesit e mësipërm janë ende brenda llogarish dhe do të humbin të dhëna për shkak të fikjes, jeni i sigurt se doni të fiket?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Përdoruesit e mësipërm janë ende brenda llogarish dhe do të humbin të dhëna për shkak të rinisjes, jeni i sigurt se doni të riniset?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Keni aktivizuar shkallën e lartë të sigurisë së sistemit, ndaj s’mund të kalohet nën mënyrën Wayland, ju lutemi, çaktivizoni shkallën e lartë të sigurisë së sistemit që nga Qendra e Sigurisë dhe riprovoni.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Fike</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Rinisu</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pezulloje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Plogështoje</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kyçe</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Dilni</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Ndërroni përdorues</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Ndërroni sistem</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Nis mbikëqyrës sistemi</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Ka programe që e pengojnë fikjen e kompjuterit, dhe fikja me zor mund të sjellë humbje të dhënash.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Që të mbyllet programi, klikoni mbi “Anuloje”, dhe mandej mbyllni programin.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Ka programe që e pengojnë rinisjen e kompjuterit, dhe rinisja me zor mund të sjellë humbje të dhënash.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Ka programe që e pengojnë pezullimin e kompjuterit, dhe pezullimi me zor mund të sjellë humbje të dhënash.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Ka programe që e pengojnë plogështimin e kompjuterit, dhe plogështimi me zor mund të sjellë humbje të dhënash.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Ka programe që e pengojnë kompjuterin të bëjë dalje nga llogaria, dhe dalja me zor mund të sjellë humbje të dhënash.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Fike</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Rinisu</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pezulloje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Plogështoje</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Dilni</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Jeni i sigurt se doni të fiket?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Jeni i sigurt se doni të riniset?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Jeni i sigurt se doni të dilet?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Aktivizoje</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Çaktivizoje</translation>
    </message>
</context>
</TS>
